@@ -1,4 +1,4 @@
-`intcox.hazard0` <-
+"intcox.hazard0" <-
 function (t, data, rate)        # baseline hazard
 {
     mini <- min(data$left)
@@ -11,4 +11,3 @@ function (t, data, rate)        # baseline hazard
     }
     return(hazard0)
 }
-
